@@ -8,6 +8,7 @@ import sys
 import tempfile
 import time
 import weakref
+from pathlib import Path
 
 import pytest
 
@@ -32,8 +33,7 @@ class TestLoaders:
         pytest.raises(TemplateNotFound, env.get_template, "missing.html")
 
     def test_filesystem_loader_overlapping_names(self, filesystem_loader):
-        res = os.path.dirname(filesystem_loader.searchpath[0])
-        t2_dir = os.path.join(res, "templates2")
+        t2_dir = Path(filesystem_loader.searchpath[0]) / ".." / "templates2"
         # Make "foo" show up before "foo/test.html".
         filesystem_loader.searchpath.insert(0, t2_dir)
         e = Environment(loader=filesystem_loader)
@@ -118,9 +118,7 @@ class TestLoaders:
 
 
 class TestFileSystemLoader:
-    searchpath = os.path.join(
-        os.path.dirname(os.path.abspath(__file__)), "res", "templates"
-    )
+    searchpath = (Path(__file__) / ".." / "res" / "templates").resolve()
 
     @staticmethod
     def _test_common(env):
@@ -131,24 +129,20 @@ class TestFileSystemLoader:
         pytest.raises(TemplateNotFound, env.get_template, "missing.html")
 
     def test_searchpath_as_str(self):
-        filesystem_loader = loaders.FileSystemLoader(self.searchpath)
+        filesystem_loader = loaders.FileSystemLoader(str(self.searchpath))
 
         env = Environment(loader=filesystem_loader)
         self._test_common(env)
 
     def test_searchpath_as_pathlib(self):
-        import pathlib
-
-        searchpath = pathlib.Path(self.searchpath)
-        filesystem_loader = loaders.FileSystemLoader(searchpath)
+        filesystem_loader = loaders.FileSystemLoader(self.searchpath)
         env = Environment(loader=filesystem_loader)
         self._test_common(env)
 
     def test_searchpath_as_list_including_pathlib(self):
-        import pathlib
-
-        searchpath = pathlib.Path(self.searchpath)
-        filesystem_loader = loaders.FileSystemLoader(["/tmp/templates", searchpath])
+        filesystem_loader = loaders.FileSystemLoader(
+            ["/tmp/templates", self.searchpath]
+        )
         env = Environment(loader=filesystem_loader)
         self._test_common(env)
 
@@ -160,7 +154,7 @@ class TestFileSystemLoader:
         tmpl2 = env.get_template("test.html")
         assert tmpl1 is tmpl2
 
-        os.utime(os.path.join(self.searchpath, "test.html"), (time.time(), time.time()))
+        os.utime(self.searchpath / "test.html", (time.time(), time.time()))
         tmpl3 = env.get_template("test.html")
         assert tmpl1 is not tmpl3
 
@@ -282,10 +276,7 @@ class TestModuleLoader:
         self.compile_down(prefix_loader)
 
         mod_path = self.mod_env.loader.module.__path__[0]
-
-        import pathlib
-
-        mod_loader = loaders.ModuleLoader(pathlib.Path(mod_path))
+        mod_loader = loaders.ModuleLoader(Path(mod_path))
         self.mod_env = Environment(loader=mod_loader)
 
         self._test_common()
@@ -294,10 +285,7 @@ class TestModuleLoader:
         self.compile_down(prefix_loader)
 
         mod_path = self.mod_env.loader.module.__path__[0]
-
-        import pathlib
-
-        mod_loader = loaders.ModuleLoader([pathlib.Path(mod_path), "/tmp/templates"])
+        mod_loader = loaders.ModuleLoader([Path(mod_path), "/tmp/templates"])
         self.mod_env = Environment(loader=mod_loader)
 
         self._test_common()
@@ -305,7 +293,7 @@ class TestModuleLoader:
 
 @pytest.fixture()
 def package_dir_loader(monkeypatch):
-    monkeypatch.syspath_prepend(os.path.dirname(__file__))
+    monkeypatch.syspath_prepend(Path(__file__).parent)
     return PackageLoader("res")
 
 
@@ -327,9 +315,8 @@ def test_package_dir_list(package_dir_loader):
 
 @pytest.fixture()
 def package_zip_loader(monkeypatch):
-    monkeypatch.syspath_prepend(
-        os.path.join(os.path.dirname(__file__), "res", "package.zip")
-    )
+    package_zip = (Path(__file__) / ".." / "res" / "package.zip").resolve()
+    monkeypatch.syspath_prepend(package_zip)
     return PackageLoader("t_pack")
 
 
